/**************************************************************************
 
 	audio.c
 
  	Project: RockBlast an asteroid game. 
 
	Copyright (c) Febuary 2001 Garett Spencley
 
   	This program is free software; you can redistribute it and/or modify
   	it under the terms of the GNU General Public License as published by
   	the Free Software Foundation; either version 2, or (at your option)
   	any later version.

   	This program is distributed in the hope that it will be useful,
   	but WITHOUT ANY WARRANTY; without even the implied warranty of
   	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   	GNU General Public License for more details.

   	You should have received a copy of the GNU General Public License
   	along with this program; if not, write to the Free Software Foundation,
   	Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 

****************************************************************************/

#include "audio.h"

#ifndef _NO_SOUND

#include <string.h>
#include <stdlib.h>

Mix_Chunk *sounds[NUM_SOUNDS];
Mix_Music *music;

char *get_sound_file(unsigned int sample);
void free_sounds(int n);

/*
 * init_audio() - initializes audio subsystem.
 */

bool init_audio()
{
	if(Mix_OpenAudio(11025, AUDIO_U8, 1, 512) < 0 ) {
		fprintf(stderr, "Warning: Couldn't set 11025 Hz 8-bit audio\n- Reason: %s\n",
							SDL_GetError());
		return false;
	}

	return true;
}

/*
 * free_audio() - frees data used by sound files
 */

void free_audio()
{
	Mix_FreeMusic(music);
	free_sounds(NUM_SOUNDS);

	Mix_CloseAudio();
}

/*
 * free_sounds() - frees all sound samples up to n
 */

void free_sounds(int n) 
{
	int i;

	for(i = 0; i < n; i++) 
		Mix_FreeChunk(sounds[i]);
}

/*
 * load_audio() - load audio files 
 */

bool load_audio()
{
	char *path, *file;
	int i;

	music = Mix_LoadMUS(DATAFILE("music.it"));
	if(!music) 
		fprintf(stderr, "Unable to open %s\n", DATAFILE("music.it"));

	for(i = 0; i < NUM_SOUNDS; i++) {

		file = get_sound_file(i);
		if(!file) {
			fprintf(stderr, "out of memory.\n");
			free_sounds(i);
			return false;
		}

		path = data_file(file);
		if(!path) {
			fprintf(stderr, "out of memory.\n");
			free(file);
			free_sounds(i);
			return false;
		}
		free(file);

		sounds[i] = Mix_LoadWAV(path);
		if(!sounds[i]) {
			fprintf(stderr, "Unable to open %s\n", data_file(file));
			free_sounds(i);
			return false;
		}

		free(path);
	}

	return true;
}

/*
 * get_sound_file() - return the sound file for sample
 */

char *get_sound_file(unsigned int sample)
{
	switch(sample) {
		case DIE: 		return strdup("die.wav");
		case BLOWUP:	return strdup("blowup.wav");
		case ONEUP:		return strdup("yahoo.wav");
		case BUMP:		return strdup("bump.wav");
		case BONUS:		return strdup("woohoo.wav");
		default:		return NULL;
	}

	return NULL;
}

/*
 * loop_music() - loop the music
 */

void loop_music()
{
	if(!Mix_PlayingMusic())
		Mix_PlayMusic(music, 0);

	return;
}

/*
 * play_sample() - play a sound file
 */

void play_sample(unsigned int samp)
{
	if(!sounds[samp])
		return;

	Mix_PlayChannel(samp, sounds[samp], 0);
}

#else


#ifndef __GNUC__
bool init_audio() { return true; }
bool load_audio() { return true; }
void loop_music() {}
void play_sample(unsigned int x) {}
void free_audio() {}
#endif

#endif
