/**************************************************************************
 
 	lives.c 
 
  	Project: RockBlast an asteroid game. 
 
	Copyright (c) Febuary 2001 Garett Spencley
 
   	This program is free software; you can redistribute it and/or modify
   	it under the terms of the GNU General Public License as published by
   	the Free Software Foundation; either version 2, or (at your option)
   	any later version.

   	This program is distributed in the hope that it will be useful,
   	but WITHOUT ANY WARRANTY; without even the implied warranty of
   	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   	GNU General Public License for more details.

   	You should have received a copy of the GNU General Public License
   	along with this program; if not, write to the Free Software Foundation,
   	Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 

****************************************************************************/


#include "ball.h"
#include "lives.h"
#include "video.h"

#define LIFE_Y_OFFSET 5
#define LIFE_X_OFFSET 10

object lives[MAX_LIVES];

/*
 * init_lives() - setup the initial lives meter
 */

bool init_lives(ball_t *ball)
{
	int i;

	for(i = 0; i < ball->remaining; i++)
		lives[i].image = ball->obj.image;

	lives[0].x = screen->w - lives[0].image->w - LIFE_X_OFFSET;
	lives[0].y = screen->h - lives[0].image->h - LIFE_Y_OFFSET;

	for(i = 1; i < ball->remaining; i++) {
		lives[i].x = (lives[i-1].x - lives[i-1].image->w) - LIFE_X_OFFSET;
		lives[i].y = screen->h - lives[i].image->h - LIFE_Y_OFFSET;
	
	}

	for(i = 0; i < ball->remaining; i++)
		draw_object(&lives[i]);

	return true;
}

/*
 * add_life() - gives 'ball' another chance
 */

void add_life(ball_t *ball)
{
	int i;

	if(!ball) 
		return;

	if(ball->remaining >= MAX_LIVES)
		return;

	i = (ball->remaining)++;

	lives[i].image = ball->obj.image;

	if(i == 0) 
		lives[i].x = screen->w - lives[i].image->w - LIFE_X_OFFSET;
	else
		lives[i].x = (lives[i-1].x - lives[i-1].image->w) - LIFE_X_OFFSET;

	lives[i].y = screen->h - lives[i].image->h - LIFE_Y_OFFSET;
}

/* 
 * draw_lives() - draws how many lives remain in 'ball'
 */

void draw_lives(ball_t *ball)
{
	int i;

	for(i = 0; i < ball->remaining; i++) 
		draw_object(&lives[i]);
}

/* 
 * take_life() - remove a life from 'ball'
 */

void take_life(ball_t *ball)
{
	--ball->remaining;		
}
