/***************************************************************************
 	paddle.c
 
  	Project: RockBlast an asteroid game. 
 
	Copyright (c) Febuary 2001 Garett Spencley
 
   	This program is free software; you can redistribute it and/or modify
   	it under the terms of the GNU General Public License as published by
   	the Free Software Foundation; either version 2, or (at your option)
   	any later version.

   	This program is distributed in the hope that it will be useful,
   	but WITHOUT ANY WARRANTY; without even the implied warranty of
   	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   	GNU General Public License for more details.

   	You should have received a copy of the GNU General Public License
   	along with this program; if not, write to the Free Software Foundation,
   	Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 

*****************************************************************************/

#include <math.h>

#include "paddle.h"
#include "video.h"

#define PADDLE_Y_OFFSET 30

/* 
 * move_paddle() - move the paddle right or left 
 */

void move_paddle(paddle_t *paddle, p_direction direction)
{
	if(paddle->dx == 0)
		paddle->dx = 1;

	switch(direction) {

	case PADDLE_LEFT:
		paddle->dx = -(abs(paddle->dx));
		break;

	case PADDLE_RIGHT:
		paddle->dx = abs(paddle->dx);
		break;

	default:
		break;
	}

	paddle->obj.x += paddle->dx * PADDLE_SPEED;
	
	if(paddle->obj.x < 0)
		paddle->obj.x = 0;
	else if(paddle->obj.x > screen->w - paddle->obj.image->w)
		paddle->obj.x = screen->w - paddle->obj.image->w;
}

/* 
 * init_paddle() - set up initial paddle data
 */

void init_paddle(paddle_t *paddle)
{
	paddle->obj.x = (screen->w - paddle->obj.image->w) / 2;
	paddle->obj.y = (screen->h - paddle->obj.image->h) - PADDLE_Y_OFFSET;

	paddle->dx = 0;
}

/*
 * erase_paddle() - erase the paddle 
 */

void erase_paddle(paddle_t *paddle) 
{
	erase_object(&paddle->obj);
}

/*
 * draw_paddle() - draw the paddle 
 */

void draw_paddle(paddle_t *paddle)
{
	draw_object(&paddle->obj);
}
