/**************************************************************************
 
 	rockblast.c
 
  	Project: RockBlast an asteroid game. 
 
	Copyright (c) Febuary 2001 Garett Spencley
 
   	This program is free software; you can redistribute it and/or modify
   	it under the terms of the GNU General Public License as published by
   	the Free Software Foundation; either version 2, or (at your option)
   	any later version.

   	This program is distributed in the hope that it will be useful,
   	but WITHOUT ANY WARRANTY; without even the implied warranty of
   	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   	GNU General Public License for more details.

   	You should have received a copy of the GNU General Public License
   	along with this program; if not, write to the Free Software Foundation,
   	Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 

****************************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include <time.h>
#include <string.h>

#include "audio.h"
#include "rockblast.h"
#include "ball.h"
#include "video.h"
#include "level.h"
#include "main_menu.h"
#include "score.h"
#include "number.h"

bool QUIT;
bool GAME_OVER;

/* 
 * data() - returns the full path to a file. Use this only
 * if 'file' is a variable file name. Otherwise use DATAFILE()
 * macro which is much faster. You must free() the result of
 * this function.
 */

inline char *data_file(char *file)
{
	char path[4096];	

#ifndef snprintf
	sprintf(path, "%s/%s", DATADIR, file); // FIXME: WE CAN DO BETTER THAN THIS!
#else
	snprintf(path, 4095, "%s/%s", DATADIR, file);
	path[4095] = 0;
#endif

	return strdup(path);
}

/* 
 * flush_event_queue() - eats up all pending events. 
 */

void flush_event_queue()
{
	SDL_Event event;
	while(SDL_PollEvent(&event));
}

/*
 * main()
 */

int main(int argc, char **argv)
{
	extern ball_t ball;

#ifdef __BEOS__
int counti;
char datapath[256];
for (counti=strlen(argv[0]) ; argv[0][counti]!='/' ; counti--);
strncpy(datapath, argv[0], counti);
chdir(datapath);
#endif
	
	if(!init_video())
		return -1;

	if(init_audio()) {
		if(!load_audio()) {
			fprintf(stderr, "Unable to load audio data!\n");
			return -1;
		}
	}
		
	/* Main event loop */
	
	while(!QUIT) {

		loop_music();

		main_menu();

		/* FIXME: Initial level stuff. This can't stay here. */
		
		speed_level = 1.0;
		difficulty_level = 0;

		ball.moving = false;
		ball.remaining = 3;

		GAME_OVER = false;

		init_numbers();
		init_score();
		init_level_meter();

		/* Play levels until player dies */

		while(!GAME_OVER && !QUIT) {

			if(init_level()) {
				srand(time(NULL));
				run_level();
			} else  
				GAME_OVER = QUIT = true;
		
			ball.moving = false;

			if(!GAME_OVER && !QUIT) 
				next_level();
			else {
				speed_level = 1.0;
				ball.remaining = 3;		
				difficulty_level = 1;
			}

			free_level();
		}

		free_level_meter();
		free_score();
		free_numbers();
	}
	
	free_audio();
	free_video();

	SDL_Quit();

	return 0;
}
