/**************************************************************************
 
 	score.c
 
  	Project: RockBlast an asteroid game. 
 
	Copyright (c) Febuary 2001 Garett Spencley
 
   	This program is free software; you can redistribute it and/or modify
   	it under the terms of the GNU General Public License as published by
   	the Free Software Foundation; either version 2, or (at your option)
   	any later version.

   	This program is distributed in the hope that it will be useful,
   	but WITHOUT ANY WARRANTY; without even the implied warranty of
   	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   	GNU General Public License for more details.

   	You should have received a copy of the GNU General Public License
   	along with this program; if not, write to the Free Software Foundation,
   	Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 

****************************************************************************/

#include <stdlib.h>
#include <limits.h>

#include "score.h"
#include "number.h"
#include "image.h"
#include "video.h"

object score_digit[MAX_DIGITS];
object score_text;
static int score;

/* 
 * init_score() - initializes score
 */

bool init_score()
{
	int init_x, x_offset;
	int i;

	if(!load_score()) 
		return false;

	score = 0;

	score_text.x = (screen->w / 2) - score_text.image->w - 10;
	score_text.y = screen->h - score_text.image->h - 2;

	init_x = score_text.x + score_text.image->w + 2; // screen->w / 2;
	x_offset = 0;

	for(i = 0; i < MAX_DIGITS; i++) {

		score_digit[i].image = num_get_digit(0);
			
		score_digit[i].x = init_x + x_offset;
		score_digit[i].y = screen->h - score_digit[i].image->h - 2;

		x_offset += score_digit[i].image->w + 2;
	}

	return true;
}

/* 
 * load_score_data() - load data for score 
 */

bool load_score()
{
	score_text.image = load_image(DATAFILE("score.png"), true);
	if(!score_text.image) {
		fprintf(stderr, "Unable to load %s: %s\n", DATAFILE("score.png"), SDL_GetError()); 
		return false;
	}

	return true;
}

/* 
 * reset_score() - reset the score to 0
 */

void reset_score()
{
	score = 0;
	change_score(0);
}

/* 
 * free_score() - free score data
 */

void free_score()
{
	SDL_FreeSurface(score_text.image);
}

/* 
 * change_score() - change the score to 'score' 
 */

void change_score(int score)
{
	int d;
	int i, digits;

	/* Map out the visual score */

	digits = num_digits(score);

	for(i = 0; i < digits; i++) {
		d = get_digit(score, i);
		score_digit[(MAX_DIGITS - digits) + i].image = num_get_digit(d);
	}
	
}

/* 
 * add_score() - add 'amount' onto the score
 */

void add_score(unsigned int amount) 
{
	/* Tap on the score */

	score += amount;

	if(score > MAX_SCORE || score < 0)
		score = MAX_SCORE;

	change_score(score);
}

/* 
 * sub_score() - subtrace 'amount' from score
 */

void sub_score(unsigned int amount) 
{
	score -= amount;

	if(score < 0) 
		score = 0;

	change_score(score);
}

/* 
 * draw_score() - draw the score
 */

void draw_score()
{
	int i;

	for(i = 0; i < MAX_DIGITS; i++) 
		draw_object(&score_digit[i]);
	
	draw_object(&score_text);
}

/*
 * erase_score() - erase the score
 */

void erase_score()
{
	int i;
	
	for(i = 0; i < MAX_DIGITS; i++) 
		erase_object(&score_digit[i]);

	erase_object(&score_text);
}
